mwatson.tune: A function to calulate the bandwidth for the Watson kernel...

Description Usage Arguments Value Author(s) References Examples

Description

A function to calulate the optimal bandwidth (tuning parameter) for the Watson kernel density estimator. Uses cross validation to calculate the bandwidth. ALso works for the multivariate Watson kernel density estimmator.

Usage

1

Arguments

x

A matrix or dataframe of values on S^(p-1). Should not contain NA's or NaN's

low

The lower value of the bandwdith to search.

high

The upper value of the bandwdith to search.

Value

Optimal h

The optimal bandwidth obtained through cross-validation

cv

The value of the maximised pseudo-likelihood

Author(s)

Nishan Mudalige

References

Michail Tsagris, Giorgos Athineou, Anamul Sajib, Eli Amson, Micah J. Waldstein (2018); Package "Directional", version 3.4

Examples

1
2
3
4
5
6
7
## install_github("baddstats/spherstat")
## library(spherstat)
## 
## x = rWatson(n=100, mode=c(0,0), kappa=50, win=sphwin())
## x = x[[1]]
## 
## mwatson.tune(x)

nishanmudalige/watson.kernel documentation built on May 6, 2019, 8:30 p.m.