w.kde: A function to obtain kernel density values using the Watson...

Description Usage Arguments Value Author(s) References Examples

Description

A function which provides obtain kernel density estimates using the Watson kernel density estimator for a given matrix.

Usage

1
w.kde(x)

Arguments

x

A matrix or dataframe of values on S^(p-1). Should not contain NA's or NaN's

h

The bandwidth. If left as NULL, the optimal bandwidth will be calculated using the Watson kernel density estimator.

Value

h

The bandwidth.

f

A vector of kernel density estimates.

Author(s)

Nishan Mudalige

References

Michail Tsagris, Giorgos Athineou, Anamul Sajib, Eli Amson, Micah J. Waldstein (2018); Package "Directional", version 3.4

Examples

1
2
3
4
5
6
7
## install_github("baddstats/spherstat")
## library(spherstat)
## 
## x = rWatson(n=100, mode=c(0,0), kappa=50, win=sphwin())
## x = x[[1]]
## 
## w.kde(x)

nishanmudalige/watson.kernel documentation built on May 6, 2019, 8:30 p.m.