Description Usage Arguments Value Author(s) References Examples
A function to calulate the optimal bandwidth (tuning parameter) for the Watson kernel density estimator. Uses cross validation to calculate the bandwidth. ALso works for the multivariate Watson kernel density estimmator.
1 | mwatson.tune(x)
|
x |
A matrix or dataframe of values on S^(p-1). Should not contain NA's or NaN's |
low |
The lower value of the bandwdith to search. |
high |
The upper value of the bandwdith to search. |
Optimal h |
The optimal bandwidth obtained through cross-validation |
cv |
The value of the maximised pseudo-likelihood |
Nishan Mudalige
Michail Tsagris, Giorgos Athineou, Anamul Sajib, Eli Amson, Micah J. Waldstein (2018); Package "Directional", version 3.4
1 2 3 4 5 6 7 | ## install_github("baddstats/spherstat")
## library(spherstat)
##
## x = rWatson(n=100, mode=c(0,0), kappa=50, win=sphwin())
## x = x[[1]]
##
## mwatson.tune(x)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.