Description Usage Arguments Value Author(s) References Examples
A function which provides obtain kernel density estimates using the Watson kernel density estimator for a given matrix.
1 | w.kde(x)
|
x |
A matrix or dataframe of values on S^(p-1). Should not contain NA's or NaN's |
h |
The bandwidth. If left as NULL, the optimal bandwidth will be calculated using the Watson kernel density estimator. |
h |
The bandwidth. |
f |
A vector of kernel density estimates. |
Nishan Mudalige
Michail Tsagris, Giorgos Athineou, Anamul Sajib, Eli Amson, Micah J. Waldstein (2018); Package "Directional", version 3.4
1 2 3 4 5 6 7 | ## install_github("baddstats/spherstat")
## library(spherstat)
##
## x = rWatson(n=100, mode=c(0,0), kappa=50, win=sphwin())
## x = x[[1]]
##
## w.kde(x)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.